@@ -3,10 +3,10 @@
 jarowinkler <- function(str1, str2, W_1=1/3, W_2=1/3, W_3=1/3, r=0.5)
 {
   # check type
-  if (typeof(str1) != "character" && class(str1) != "data.frame")
+  if (typeof(str1) != "character" && !is(str1, "data.frame"))
      stop(sprintf("Illegal data type: %s", typeof(str1)))
   
-  if (typeof(str2) != "character" && class(str2) != "data.frame")
+  if (typeof(str2) != "character" && !is(str2, "data.frame"))
      stop(sprintf("Illegal data type: %s", typeof(str2)))
 
    if ((is.array(str1) || is.array(str2)) && !identical(dim(str1), dim(str2)))
@@ -31,10 +31,10 @@ jarowinkler <- function(str1, str2, W_1=1/3, W_2=1/3, W_3=1/3, r=0.5)
 levenshteinDist <- function(str1, str2)
 {
    # check type
-   if (typeof(str1) != "character" && class(str1) != "data.frame")
+   if (typeof(str1) != "character" && !is(str1, "data.frame"))
       stop(sprintf("Illegal data type: %s", typeof(str1)))
    
-   if (typeof(str2) != "character" && class(str2) != "data.frame")
+   if (typeof(str2) != "character" && !is(str2, "data.frame"))
       stop(sprintf("Illegal data type: %s", typeof(str2)))
    if ((is.array(str1) || is.array(str2)) && !identical(dim(str1), dim(str2)))
       stop ("non-conformable arrays")
